abacusai.hostname_info — AbacusAI documentation

# abacusai.hostname_info

## Classes

`HostnameInfo` | Hostname Info

## Module Contents

class abacusai.hostname_info.HostnameInfo(client, isRootDomain=None, registrar=None, suggestedFlow=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Hostname Info

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - isRootDomain (bool) – Whether the hostname is a root domain

    - registrar (str) – The registrar of the domain

    - suggestedFlow (str) – Suggested flow for the domain

  is_root_domain = None
  registrar = None
  suggested_flow = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict